package com.bayread.sensors.task;

import cn.hutool.core.util.ZipUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.bayread.sensors.batch.impl.MultipleWorkerEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import sun.misc.BASE64Decoder;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.List;

public class LogsHandleWorker implements MultipleWorkerEvent<String> {
    private static final Logger ADAPTER_ERROR_LOG = LoggerFactory.getLogger("adapter.error");
    private static final Logger SYS_ERROR_LOG = LoggerFactory.getLogger("sys.error");
    private static final String TOPIC = "ets_app_topic";
    private KafkaTemplate<String, String> kafka;

    public LogsHandleWorker(KafkaTemplate<String, String> kafka){
        this.kafka = kafka;
    }

    @Override
    public void handle(List<String> list) {
        if(list.size() == 0){return;}

        list.forEach(log ->{
            try {
                handle(log);
            }catch (Exception ex){
                ADAPTER_ERROR_LOG.info("ERROR LOG:{}",log);
                ex.printStackTrace();
            }
        });
    }

    void handle(String logs) throws IOException {
        BASE64Decoder decoder = new BASE64Decoder();
        byte[] dbyte = decoder.decodeBuffer(logs);

        JSONArray ja = JSON.parseArray(new String(ZipUtil.unGzip(dbyte), StandardCharsets.UTF_8));

        for(int i=0;i<ja.size();i++) {
            send(ja.getJSONObject(i).toString());
        }
    }

    public void send(String log){
        kafka.send(TOPIC,log);
    }

    @Override
    public void handleException(Object obj, Exception ex) {
        SYS_ERROR_LOG.error("LogsHandleWorker Exception:",ex);
    }
}